Contributing
============

If you notice a bug, have a suggestion for a new feature, or find that that
something just isn't behaving the way you'd expect it to, please submit an
issue to our `issue tracker`_.

If you'd like to contribute code to our repository, you can do so by issuing a
pull request and we will work with you to try and integrate that code into our
repository.  Users who want to contribute code to the python-cybox repository
should be familiar with git_ and the `GitHub pull request process`_.

.. _issue tracker: https://github.com/CybOXProject/python-cybox/issues
.. _git: http://git-scm.com/documentation
.. _GitHub pull request process: https://help.github.com/articles/using-pull-requests
